
# Slot: maximum_cardinality


the maximum number of entries for a multivalued slot

URI: [linkml:maximum_cardinality](https://w3id.org/linkml/maximum_cardinality)


## Domain and Range

None &#8594;  <sub>0..1</sub> integer

## Parents

 *  is_a: value_specification_constant

## Children


## Used by

 * anonymous_slot_expression
 * slot_definition
 * slot_expression
